@@ -16,32 +16,32 @@ from datetime import datetime
 from typing import Any, Dict, List
 
 from .literals import (
-    ArtifactNamespace,
-    ArtifactPackaging,
-    ArtifactsType,
-    AuthType,
-    BucketOwnerAccess,
-    BuildBatchPhaseType,
-    BuildPhaseType,
-    CacheMode,
-    CacheType,
-    ComputeType,
-    EnvironmentType,
-    EnvironmentVariableType,
-    ImagePullCredentialsType,
-    LanguageType,
-    LogsConfigStatusType,
-    PlatformType,
-    ReportExportConfigType,
-    ReportGroupStatusType,
-    ReportPackagingType,
-    ReportStatusType,
-    ReportType,
-    ServerType,
-    SourceType,
-    StatusType,
-    WebhookBuildType,
-    WebhookFilterType,
+    ArtifactNamespaceType,
+    ArtifactPackagingType,
+    ArtifactsTypeType,
+    AuthTypeType,
+    BucketOwnerAccessType,
+    BuildBatchPhaseTypeType,
+    BuildPhaseTypeType,
+    CacheModeType,
+    CacheTypeType,
+    ComputeTypeType,
+    EnvironmentTypeType,
+    EnvironmentVariableTypeType,
+    ImagePullCredentialsTypeType,
+    LanguageTypeType,
+    LogsConfigStatusTypeType,
+    PlatformTypeType,
+    ReportExportConfigTypeType,
+    ReportGroupStatusTypeType,
+    ReportPackagingTypeType,
+    ReportStatusTypeType,
+    ReportTypeType,
+    ServerTypeType,
+    SourceTypeType,
+    StatusTypeType,
+    WebhookBuildTypeType,
+    WebhookFilterTypeType,
 )
 
 if sys.version_info >= (3, 8):
@@ -222,7 +222,7 @@ BuildArtifactsTypeDef = TypedDict(
         "overrideArtifactName": bool,
         "encryptionDisabled": bool,
         "artifactIdentifier": str,
-        "bucketOwnerAccess": BucketOwnerAccess,
+        "bucketOwnerAccess": BucketOwnerAccessType,
     },
     total=False,
 )
@@ -230,7 +230,7 @@ BuildArtifactsTypeDef = TypedDict(
 BuildBatchFilterTypeDef = TypedDict(
     "BuildBatchFilterTypeDef",
     {
-        "status": StatusType,
+        "status": StatusTypeType,
     },
     total=False,
 )
@@ -238,8 +238,8 @@ BuildBatchFilterTypeDef = TypedDict(
 BuildBatchPhaseTypeDef = TypedDict(
     "BuildBatchPhaseTypeDef",
     {
-        "phaseType": BuildBatchPhaseType,
-        "phaseStatus": StatusType,
+        "phaseType": BuildBatchPhaseTypeType,
+        "phaseStatus": StatusTypeType,
         "startTime": datetime,
         "endTime": datetime,
         "durationInSeconds": int,
@@ -256,7 +256,7 @@ BuildBatchTypeDef = TypedDict(
         "startTime": datetime,
         "endTime": datetime,
         "currentPhase": str,
-        "buildBatchStatus": StatusType,
+        "buildBatchStatus": StatusTypeType,
         "sourceVersion": str,
         "resolvedSourceVersion": str,
         "projectName": str,
@@ -309,8 +309,8 @@ BuildNotDeletedTypeDef = TypedDict(
 BuildPhaseTypeDef = TypedDict(
     "BuildPhaseTypeDef",
     {
-        "phaseType": BuildPhaseType,
-        "phaseStatus": StatusType,
+        "phaseType": BuildPhaseTypeType,
+        "phaseStatus": StatusTypeType,
         "startTime": datetime,
         "endTime": datetime,
         "durationInSeconds": int,
@@ -333,7 +333,7 @@ BuildSummaryTypeDef = TypedDict(
     {
         "arn": str,
         "requestedOn": datetime,
-        "buildStatus": StatusType,
+        "buildStatus": StatusTypeType,
         "primaryArtifact": "ResolvedArtifactTypeDef",
         "secondaryArtifacts": List["ResolvedArtifactTypeDef"],
     },
@@ -349,7 +349,7 @@ BuildTypeDef = TypedDict(
         "startTime": datetime,
         "endTime": datetime,
         "currentPhase": str,
-        "buildStatus": StatusType,
+        "buildStatus": StatusTypeType,
         "sourceVersion": str,
         "resolvedSourceVersion": str,
         "projectName": str,
@@ -382,7 +382,7 @@ BuildTypeDef = TypedDict(
 _RequiredCloudWatchLogsConfigTypeDef = TypedDict(
     "_RequiredCloudWatchLogsConfigTypeDef",
     {
-        "status": LogsConfigStatusType,
+        "status": LogsConfigStatusTypeType,
     },
 )
 _OptionalCloudWatchLogsConfigTypeDef = TypedDict(
@@ -513,7 +513,7 @@ EnvironmentImageTypeDef = TypedDict(
 EnvironmentLanguageTypeDef = TypedDict(
     "EnvironmentLanguageTypeDef",
     {
-        "language": LanguageType,
+        "language": LanguageTypeType,
         "images": List["EnvironmentImageTypeDef"],
     },
     total=False,
@@ -522,7 +522,7 @@ EnvironmentLanguageTypeDef = TypedDict(
 EnvironmentPlatformTypeDef = TypedDict(
     "EnvironmentPlatformTypeDef",
     {
-        "platform": PlatformType,
+        "platform": PlatformTypeType,
         "languages": List["EnvironmentLanguageTypeDef"],
     },
     total=False,
@@ -538,7 +538,7 @@ _RequiredEnvironmentVariableTypeDef = TypedDict(
 _OptionalEnvironmentVariableTypeDef = TypedDict(
     "_OptionalEnvironmentVariableTypeDef",
     {
-        "type": EnvironmentVariableType,
+        "type": EnvironmentVariableTypeType,
     },
     total=False,
 )
@@ -752,7 +752,7 @@ PhaseContextTypeDef = TypedDict(
 _RequiredProjectArtifactsTypeDef = TypedDict(
     "_RequiredProjectArtifactsTypeDef",
     {
-        "type": ArtifactsType,
+        "type": ArtifactsTypeType,
     },
 )
 _OptionalProjectArtifactsTypeDef = TypedDict(
@@ -760,13 +760,13 @@ _OptionalProjectArtifactsTypeDef = TypedDict(
     {
         "location": str,
         "path": str,
-        "namespaceType": ArtifactNamespace,
+        "namespaceType": ArtifactNamespaceType,
         "name": str,
-        "packaging": ArtifactPackaging,
+        "packaging": ArtifactPackagingType,
         "overrideArtifactName": bool,
         "encryptionDisabled": bool,
         "artifactIdentifier": str,
-        "bucketOwnerAccess": BucketOwnerAccess,
+        "bucketOwnerAccess": BucketOwnerAccessType,
     },
     total=False,
 )
@@ -799,14 +799,14 @@ ProjectBuildBatchConfigTypeDef = TypedDict(
 _RequiredProjectCacheTypeDef = TypedDict(
     "_RequiredProjectCacheTypeDef",
     {
-        "type": CacheType,
+        "type": CacheTypeType,
     },
 )
 _OptionalProjectCacheTypeDef = TypedDict(
     "_OptionalProjectCacheTypeDef",
     {
         "location": str,
-        "modes": List[CacheMode],
+        "modes": List[CacheModeType],
     },
     total=False,
 )
@@ -819,9 +819,9 @@ class ProjectCacheTypeDef(_RequiredProjectCacheTypeDef, _OptionalProjectCacheTyp
 _RequiredProjectEnvironmentTypeDef = TypedDict(
     "_RequiredProjectEnvironmentTypeDef",
     {
-        "type": EnvironmentType,
+        "type": EnvironmentTypeType,
         "image": str,
-        "computeType": ComputeType,
+        "computeType": ComputeTypeType,
     },
 )
 _OptionalProjectEnvironmentTypeDef = TypedDict(
@@ -831,7 +831,7 @@ _OptionalProjectEnvironmentTypeDef = TypedDict(
         "privilegedMode": bool,
         "certificate": str,
         "registryCredential": "RegistryCredentialTypeDef",
-        "imagePullCredentialsType": ImagePullCredentialsType,
+        "imagePullCredentialsType": ImagePullCredentialsTypeType,
     },
     total=False,
 )
@@ -858,7 +858,7 @@ ProjectFileSystemLocationTypeDef = TypedDict(
 _RequiredProjectSourceTypeDef = TypedDict(
     "_RequiredProjectSourceTypeDef",
     {
-        "type": SourceType,
+        "type": SourceTypeType,
     },
 )
 _OptionalProjectSourceTypeDef = TypedDict(
@@ -941,7 +941,7 @@ RegistryCredentialTypeDef = TypedDict(
 ReportExportConfigTypeDef = TypedDict(
     "ReportExportConfigTypeDef",
     {
-        "exportConfigType": ReportExportConfigType,
+        "exportConfigType": ReportExportConfigTypeType,
         "s3Destination": "S3ReportExportConfigTypeDef",
     },
     total=False,
@@ -950,7 +950,7 @@ ReportExportConfigTypeDef = TypedDict(
 ReportFilterTypeDef = TypedDict(
     "ReportFilterTypeDef",
     {
-        "status": ReportStatusType,
+        "status": ReportStatusTypeType,
     },
     total=False,
 )
@@ -970,12 +970,12 @@ ReportGroupTypeDef = TypedDict(
     {
         "arn": str,
         "name": str,
-        "type": ReportType,
+        "type": ReportTypeType,
         "exportConfig": "ReportExportConfigTypeDef",
         "created": datetime,
         "lastModified": datetime,
         "tags": List["TagTypeDef"],
-        "status": ReportGroupStatusType,
+        "status": ReportGroupStatusTypeType,
     },
     total=False,
 )
@@ -984,11 +984,11 @@ ReportTypeDef = TypedDict(
     "ReportTypeDef",
     {
         "arn": str,
-        "type": ReportType,
+        "type": ReportTypeType,
         "name": str,
         "reportGroupArn": str,
         "executionId": str,
-        "status": ReportStatusType,
+        "status": ReportStatusTypeType,
         "created": datetime,
         "expired": datetime,
         "exportConfig": "ReportExportConfigTypeDef",
@@ -1011,7 +1011,7 @@ ReportWithRawDataTypeDef = TypedDict(
 ResolvedArtifactTypeDef = TypedDict(
     "ResolvedArtifactTypeDef",
     {
-        "type": ArtifactsType,
+        "type": ArtifactsTypeType,
         "location": str,
         "identifier": str,
     },
@@ -1048,7 +1048,7 @@ RetryBuildOutputTypeDef = TypedDict(
 _RequiredS3LogsConfigTypeDef = TypedDict(
     "_RequiredS3LogsConfigTypeDef",
     {
-        "status": LogsConfigStatusType,
+        "status": LogsConfigStatusTypeType,
     },
 )
 _OptionalS3LogsConfigTypeDef = TypedDict(
@@ -1056,7 +1056,7 @@ _OptionalS3LogsConfigTypeDef = TypedDict(
     {
         "location": str,
         "encryptionDisabled": bool,
-        "bucketOwnerAccess": BucketOwnerAccess,
+        "bucketOwnerAccess": BucketOwnerAccessType,
     },
     total=False,
 )
@@ -1072,7 +1072,7 @@ S3ReportExportConfigTypeDef = TypedDict(
         "bucket": str,
         "bucketOwner": str,
         "path": str,
-        "packaging": ReportPackagingType,
+        "packaging": ReportPackagingTypeType,
         "encryptionKey": str,
         "encryptionDisabled": bool,
     },
@@ -1102,8 +1102,8 @@ SourceCredentialsInfoTypeDef = TypedDict(
     "SourceCredentialsInfoTypeDef",
     {
         "arn": str,
-        "serverType": ServerType,
-        "authType": AuthType,
+        "serverType": ServerTypeType,
+        "authType": AuthTypeType,
     },
     total=False,
 )
@@ -1219,7 +1219,7 @@ VpcConfigTypeDef = TypedDict(
 _RequiredWebhookFilterTypeDef = TypedDict(
     "_RequiredWebhookFilterTypeDef",
     {
-        "type": WebhookFilterType,
+        "type": WebhookFilterTypeType,
         "pattern": str,
     },
 )
@@ -1244,7 +1244,7 @@ WebhookTypeDef = TypedDict(
         "secret": str,
         "branchFilter": str,
         "filterGroups": List[List["WebhookFilterTypeDef"]],
-        "buildType": WebhookBuildType,
+        "buildType": WebhookBuildTypeType,
         "lastModifiedSecret": datetime,
     },
     total=False,
